@@ -5,8 +5,8 @@
 ;; Author: Bibek Panthi <bpanthi977@gmail.com>
 ;; Maintainer: Bibek Panthi <bpanthi977@gmail.com>
 ;; URL: https://github.com/bpanthi977/org-mpv-notes
-;; Package-Version: 20241222.1958
-;; Package-Revision: 1d8db9ff8031
+;; Package-Version: 20260224.1801
+;; Package-Revision: bb0e6b2dd5a9
 ;; Package-Requires: ((emacs "28.1"))
 ;; Kewords: mpv, org
 
@@ -208,7 +208,8 @@ Returns path (string)
                                      org-mpv-notes-mpv-args))
            (mpv-default-options org-mpv-notes-mpv-args)
            (empv-mpv-args (when (boundp 'empv-mpv-args)
-                            (append empv-mpv-args org-mpv-notes-mpv-args))))
+                            (cons (format "--input-ipc-server=%s" empv-socket-file)
+				  org-mpv-notes-mpv-args))))
       (cl-flet ((start (path)
                   (let ((path (if (string-prefix-p "http" path)
                                   path
@@ -221,7 +222,7 @@ Returns path (string)
         ;; Open mpv player
         (cond ((not (org-mpv-notes--active-backend t))
                (start path))
-              ((not (string-equal (org-mpv-notes--get-property "path") path))
+              ((not (string-equal (ignore-errors (org-mpv-notes--get-property "path")) path))
                (org-mpv-notes-kill)
                (sleep-for org-mpv-notes-empv-wait-interval)
                (start path))
